@@ -28,7 +28,7 @@ Korean_LO_Latest_main
    <fa>Korean localisation of LibreOffice</fa>
    <fil_PH>Korean localisation of LibreOffice</fil_PH>
    <fi>Korealainen kotoistus LibreOffice:lle</fi>
-   <fr_BE>Localisation en coréen pour LibreOffice</fr_BE>
+   <fr_BE>Korean localisation of LibreOffice</fr_BE>
    <fr>Localisation en coréen pour LibreOffice</fr>
    <gl_ES>Localización do LibreOffice ao coreano</gl_ES>
    <gu>Korean localisation of LibreOffice</gu>
@@ -42,7 +42,6 @@ Korean_LO_Latest_main
    <ja>LibreOffice の韓国（朝鮮）語版</ja>
    <kk>Korean localisation of LibreOffice</kk>
    <ko>Korean localisation of LibreOffice</ko>
-   <ku>Korean localisation of LibreOffice</ku>
    <lt>Korean localisation of LibreOffice</lt>
    <mk>Korean localisation of LibreOffice</mk>
    <mr>Korean localisation of LibreOffice</mr>
@@ -50,16 +49,14 @@ Korean_LO_Latest_main
    <nb>Koreansk lokaltilpassing av LibreOffice</nb>
    <nl_BE>Korean localisation of LibreOffice</nl_BE>
    <nl>Koreaanse lokalisatie van LibreOffice</nl>
-   <or>Korean localisation of LibreOffice</or>
    <pl>Koreańska lokalizacja LibreOffice</pl>
    <pt_BR>Coreano Localização para o LibreOffice</pt_BR>
    <pt>Coreano Localização para LibreOffice</pt>
    <ro>Korean localisation of LibreOffice</ro>
    <ru>Korean localisation of LibreOffice</ru>
    <sk>Korean localisation of LibreOffice</sk>
-   <sl>Korejske krajevne nastavitve za LibreOffice</sl>
-   <so>Korean localisation of LibreOffice</so>
-   <sq>Përkthim i LibreOffice-it në koreançe</sq>
+   <sl>Korean localisation of LibreOffice</sl>
+   <sq>Korean localisation of LibreOffice</sq>
    <sr>Korean localisation of LibreOffice</sr>
    <sv>Koreansk lokalisering av LibreOffice</sv>
    <th>Korean localisation ของ LibreOffice</th>
